.. Copyright (c) 2016, Johan Mabille, Sylvain Corlay and Wolf Vollprecht

   Distributed under the terms of the BSD 3-Clause License.

   The full license is in the file LICENSE, distributed with this software.

xoptional_assembly_base
=======================

Defined in ``xtensor/xoptional_assembly_base.hpp``

.. doxygenclass:: xt::xoptional_assembly_base
   :project: xtensor
   :members:
